@@ -25,16 +25,17 @@ OC.L10N.register(
     "Copy link" : "Copiar enlace",
     "Edit" : "Editar",
     "Delete" : "Borrar",
+    "Create new" : "Crear nuevo",
     "Calendars" : "Calendarios",
     "New calendar" : "Nuevo calendario",
     "New calendar with task list" : "Nuevo calendario con listado de tareas",
     "Copied link" : "Link copiado",
     "Export" : "Exportar",
+    "Empty trash bin" : "Vaciar la papelera",
     "Name" : "Nombre",
     "Deleted" : "Eliminado",
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
-    "Empty trash bin" : "Vaciar la papelera",
     "Deck" : "Deck",
     "Hidden" : "Oculto",
     "Copy internal link" : "Copiar enlace interno",
@@ -51,8 +52,10 @@ OC.L10N.register(
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
+    "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "Visibility" : "Visibilidad",
     "to" : "para",
     "Add" : "Añadir",
     "Monday" : "Lunes",
@@ -62,29 +65,35 @@ OC.L10N.register(
     "Friday" : "Viernes",
     "Saturday" : "Sábado",
     "Sunday" : "Domingo",
-    "Update" : "Actualizar",
     "Your email address" : "Su dirección de correo electrónico",
+    "Back" : "Volver",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
-    "Delete file" : "Borrar archivo",
+    "seconds" : "segundos",
+    "minutes" : "minutos",
+    "hours" : "horas",
+    "days" : "días",
+    "weeks" : "semanas",
     "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
+    "Delete file" : "Borrar archivo",
     "Available" : "Disponible",
     "Not available" : "No disponible",
-    "Done" : "Terminado",
     "Unknown" : "Desconocido",
+    "Done" : "Terminado",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
     "Attendees" : "Asistentes",
+    "Remove group" : "Eliminar grupo",
     "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "never" : "nunca",
     "after" : "después",
     "first" : "primero",
-    "last" : "último",
     "available" : "disponible",
     "Global" : "Global",
     "Subscribe" : "Suscribirse",
+    "Select a date" : "Elija una fecha",
     "Personal" : "Personal",
     "Details" : "Detalles",
     "Resources" : "Recursos",
@@ -93,6 +102,8 @@ OC.L10N.register(
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
+    "second" : "segundo",
+    "last" : "último",
     "Other" : "Otro",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
